# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.IsolatedAsyncioTestCase):
    """OrganizationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OrganizationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_organization_organizations_post(self) -> None:
        """Test case for create_organization_organizations_post

        Create Organization
        """
        pass

    async def test_delete_organization_organizations_organization_id_delete(self) -> None:
        """Test case for delete_organization_organizations_organization_id_delete

        Delete Organization
        """
        pass

    async def test_get_organization_by_inn_organizations_by_inn_inn_get(self) -> None:
        """Test case for get_organization_by_inn_organizations_by_inn_inn_get

        Get Organization By Inn
        """
        pass

    async def test_get_organization_organizations_organization_id_get(self) -> None:
        """Test case for get_organization_organizations_organization_id_get

        Get Organization
        """
        pass

    async def test_list_organizations_organizations_get(self) -> None:
        """Test case for list_organizations_organizations_get

        List Organizations
        """
        pass

    async def test_update_organization_organizations_organization_id_patch(self) -> None:
        """Test case for update_organization_organizations_organization_id_patch

        Update Organization
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from sromaster.models.accordance_status import AccordanceStatus
from sromaster.models.check_disciplinary_action import CheckDisciplinaryAction
from sromaster.models.check_out import CheckOut
from sromaster.models.check_result import CheckResult
from sromaster.models.check_type import CheckType
from sromaster.models.check_upsert_request import CheckUpsertRequest
from sromaster.models.customer_create import CustomerCreate
from sromaster.models.customer_email_in import CustomerEmailIn
from sromaster.models.customer_email_out import CustomerEmailOut
from sromaster.models.customer_out import CustomerOut
from sromaster.models.customer_phone_in import CustomerPhoneIn
from sromaster.models.customer_phone_out import CustomerPhoneOut
from sromaster.models.customer_status import CustomerStatus
from sromaster.models.customer_update import CustomerUpdate
from sromaster.models.email_search_status import EmailSearchStatus
from sromaster.models.http_validation_error import HTTPValidationError
from sromaster.models.im_insurer_create import IMInsurerCreate
from sromaster.models.im_insurer_out import IMInsurerOut
from sromaster.models.im_insurer_update import IMInsurerUpdate
from sromaster.models.im_mailing_create import IMMailingCreate
from sromaster.models.im_mailing_invoice_out import IMMailingInvoiceOut
from sromaster.models.im_mailing_invoice_summary import IMMailingInvoiceSummary
from sromaster.models.im_mailing_out_input import IMMailingOutInput
from sromaster.models.im_mailing_out_output import IMMailingOutOutput
from sromaster.models.im_mailing_update import IMMailingUpdate
from sromaster.models.im_sro_public import IMSroPublic
from sromaster.models.im_sro_upsert_request import IMSroUpsertRequest
from sromaster.models.insurance_out import InsuranceOut
from sromaster.models.insurance_premium import InsurancePremium
from sromaster.models.insurance_upsert_request import InsuranceUpsertRequest
from sromaster.models.insured_sum import InsuredSum
from sromaster.models.invoice_finalize_request import InvoiceFinalizeRequest
from sromaster.models.invoice_status import InvoiceStatus
from sromaster.models.invoice_upload_url_request import InvoiceUploadUrlRequest
from sromaster.models.invoice_upload_url_response import InvoiceUploadUrlResponse
from sromaster.models.legal_form import LegalForm
from sromaster.models.mailing_result import MailingResult
from sromaster.models.mailing_status import MailingStatus
from sromaster.models.member_status import MemberStatus
from sromaster.models.message_status import MessageStatus
from sromaster.models.organization_create import OrganizationCreate
from sromaster.models.organization_email_create import OrganizationEmailCreate
from sromaster.models.organization_email_out import OrganizationEmailOut
from sromaster.models.organization_email_update import OrganizationEmailUpdate
from sromaster.models.organization_out import OrganizationOut
from sromaster.models.organization_public import OrganizationPublic
from sromaster.models.organization_schema import OrganizationSchema
from sromaster.models.organization_update import OrganizationUpdate
from sromaster.models.page_customer_out_input import PageCustomerOutInput
from sromaster.models.page_customer_out_output import PageCustomerOutOutput
from sromaster.models.page_im_insurer_out_input import PageIMInsurerOutInput
from sromaster.models.page_im_insurer_out_output import PageIMInsurerOutOutput
from sromaster.models.page_im_mailing_invoice_out import PageIMMailingInvoiceOut
from sromaster.models.page_im_mailing_out_input import PageIMMailingOutInput
from sromaster.models.page_im_mailing_out_output import PageIMMailingOutOutput
from sromaster.models.page_im_sro_public_input import PageIMSroPublicInput
from sromaster.models.page_im_sro_public_output import PageIMSroPublicOutput
from sromaster.models.page_insurance_out import PageInsuranceOut
from sromaster.models.page_organization_email_out import PageOrganizationEmailOut
from sromaster.models.page_organization_out_input import PageOrganizationOutInput
from sromaster.models.page_organization_out_output import PageOrganizationOutOutput
from sromaster.models.page_sro_member_list_item_input import PageSROMemberListItemInput
from sromaster.models.page_sro_member_list_item_output import PageSROMemberListItemOutput
from sromaster.models.page_sro_public_input import PageSROPublicInput
from sromaster.models.page_sro_public_output import PageSROPublicOutput
from sromaster.models.participation_status import ParticipationStatus
from sromaster.models.response_data_customer_email_out import ResponseDataCustomerEmailOut
from sromaster.models.response_data_customer_out import ResponseDataCustomerOut
from sromaster.models.response_data_customer_phone_out import ResponseDataCustomerPhoneOut
from sromaster.models.response_data_im_insurer_out import ResponseDataIMInsurerOut
from sromaster.models.response_data_im_mailing_invoice_out import ResponseDataIMMailingInvoiceOut
from sromaster.models.response_data_im_mailing_out import ResponseDataIMMailingOut
from sromaster.models.response_data_im_sro_public import ResponseDataIMSroPublic
from sromaster.models.response_data_insurance_out import ResponseDataInsuranceOut
from sromaster.models.response_data_invoice_upload_url_response import ResponseDataInvoiceUploadUrlResponse
from sromaster.models.response_data_list_customer_email_out import ResponseDataListCustomerEmailOut
from sromaster.models.response_data_list_customer_phone_out import ResponseDataListCustomerPhoneOut
from sromaster.models.response_data_list_im_mailing_out import ResponseDataListIMMailingOut
from sromaster.models.response_data_list_organization_email_out import ResponseDataListOrganizationEmailOut
from sromaster.models.response_data_organization_email_out import ResponseDataOrganizationEmailOut
from sromaster.models.response_data_organization_out import ResponseDataOrganizationOut
from sromaster.models.response_data_page_customer_out import ResponseDataPageCustomerOut
from sromaster.models.response_data_page_im_insurer_out import ResponseDataPageIMInsurerOut
from sromaster.models.response_data_page_im_mailing_invoice_out import ResponseDataPageIMMailingInvoiceOut
from sromaster.models.response_data_page_im_mailing_out import ResponseDataPageIMMailingOut
from sromaster.models.response_data_page_im_sro_public import ResponseDataPageIMSroPublic
from sromaster.models.response_data_page_insurance_out import ResponseDataPageInsuranceOut
from sromaster.models.response_data_page_organization_email_out import ResponseDataPageOrganizationEmailOut
from sromaster.models.response_data_page_organization_out import ResponseDataPageOrganizationOut
from sromaster.models.response_data_page_sro_member_list_item import ResponseDataPageSROMemberListItem
from sromaster.models.response_data_page_sro_public import ResponseDataPageSROPublic
from sromaster.models.response_data_sro_member_details import ResponseDataSROMemberDetails
from sromaster.models.response_data_sro_public import ResponseDataSROPublic
from sromaster.models.response_data_str import ResponseDataStr
from sromaster.models.response_data_user_response import ResponseDataUserResponse
from sromaster.models.responsibility_level import ResponsibilityLevel
from sromaster.models.right_status import RightStatus
from sromaster.models.sro_member_details_input import SROMemberDetailsInput
from sromaster.models.sro_member_details_output import SROMemberDetailsOutput
from sromaster.models.sro_member_list_item_input import SROMemberListItemInput
from sromaster.models.sro_member_list_item_output import SROMemberListItemOutput
from sromaster.models.sro_member_upsert_request import SROMemberUpsertRequest
from sromaster.models.sro_public import SROPublic
from sromaster.models.sro_short import SROShort
from sromaster.models.sro_status import SROStatus
from sromaster.models.sro_upsert_request import SROUpsertRequest
from sromaster.models.source_registry import SourceRegistry
from sromaster.models.src_models_sro_member_registry import SrcModelsSroMemberRegistry
from sromaster.models.tariff_entry import TariffEntry
from sromaster.models.user_response import UserResponse
from sromaster.models.validation_error import ValidationError
from sromaster.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.insurances_api import InsurancesApi


class TestInsurancesApi(unittest.IsolatedAsyncioTestCase):
    """InsurancesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = InsurancesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_get_insurance_insurances_insurance_id_get(self) -> None:
        """Test case for get_insurance_insurances_insurance_id_get

        Get Insurance
        """
        pass

    async def test_list_insurances_insurances_get(self) -> None:
        """Test case for list_insurances_insurances_get

        List Insurances
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_sro_member_details import ResponseDataSROMemberDetails

class TestResponseDataSROMemberDetails(unittest.TestCase):
    """ResponseDataSROMemberDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataSROMemberDetails:
        """Test ResponseDataSROMemberDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataSROMemberDetails`
        """
        model = ResponseDataSROMemberDetails()
        if include_optional:
            return ResponseDataSROMemberDetails(
                data = sromaster.models.sro_member_details.SROMemberDetails(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    sro = sromaster.models.sro_public.SROPublic(
                        id = 56, 
                        registry_id = 56, 
                        name = '', 
                        reg_number = '', 
                        inn = 56, 
                        ogrn = 56, 
                        address = '', 
                        phone = '', 
                        email = '', 
                        website = '', 
                        status = 'ACTIVE', 
                        exclusion_reason = '', 
                        members_count = 56, ), 
                    organization = sromaster.models.organization_public.OrganizationPublic(
                        id = 56, 
                        source_registry = 'NOPRIZ', 
                        inn = 56, 
                        ogrn = 56, 
                        legal_form = 'LEGAL_ENTITY', 
                        name_full = '', 
                        name_short = '', 
                        address = '', 
                        director_name = '', 
                        registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    registration_number = '', 
                    member_status = 'ACTIVE', 
                    included_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    excluded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    exclusion_reason = '', 
                    accordance_status = 'ACCORDANT', 
                    right_status = 'VALID', 
                    is_simple = True, 
                    is_extremely_dangerous = True, 
                    is_nuclear = True, 
                    is_odo = True, 
                    compensation_fund_fee_vv = 56, 
                    compensation_fund_fee_odo = 56, 
                    responsibility_level_vv = '1', 
                    responsibility_level_odo = '1', 
                    registry_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    insurances_count = 56, 
                    checks_count = 56, 
                    insurances = [
                        sromaster.models.insurance_out.InsuranceOut(
                            id = 56, 
                            registry_id = 56, 
                            insurer = '', 
                            address = '', 
                            insurance_object = '', 
                            amount = 56, 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    checks = [
                        sromaster.models.check_out.CheckOut(
                            id = 56, 
                            registry_id = 56, 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            type_ = 'PLANED', 
                            result = 'VIOLATION_FOUND', 
                            disciplinary_action = 'APPLIED', )
                        ], )
            )
        else:
            return ResponseDataSROMemberDetails(
                data = sromaster.models.sro_member_details.SROMemberDetails(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    sro = sromaster.models.sro_public.SROPublic(
                        id = 56, 
                        registry_id = 56, 
                        name = '', 
                        reg_number = '', 
                        inn = 56, 
                        ogrn = 56, 
                        address = '', 
                        phone = '', 
                        email = '', 
                        website = '', 
                        status = 'ACTIVE', 
                        exclusion_reason = '', 
                        members_count = 56, ), 
                    organization = sromaster.models.organization_public.OrganizationPublic(
                        id = 56, 
                        source_registry = 'NOPRIZ', 
                        inn = 56, 
                        ogrn = 56, 
                        legal_form = 'LEGAL_ENTITY', 
                        name_full = '', 
                        name_short = '', 
                        address = '', 
                        director_name = '', 
                        registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    registration_number = '', 
                    member_status = 'ACTIVE', 
                    included_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    excluded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    exclusion_reason = '', 
                    accordance_status = 'ACCORDANT', 
                    right_status = 'VALID', 
                    is_simple = True, 
                    is_extremely_dangerous = True, 
                    is_nuclear = True, 
                    is_odo = True, 
                    compensation_fund_fee_vv = 56, 
                    compensation_fund_fee_odo = 56, 
                    responsibility_level_vv = '1', 
                    responsibility_level_odo = '1', 
                    registry_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    insurances_count = 56, 
                    checks_count = 56, 
                    insurances = [
                        sromaster.models.insurance_out.InsuranceOut(
                            id = 56, 
                            registry_id = 56, 
                            insurer = '', 
                            address = '', 
                            insurance_object = '', 
                            amount = 56, 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    checks = [
                        sromaster.models.check_out.CheckOut(
                            id = 56, 
                            registry_id = 56, 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            type_ = 'PLANED', 
                            result = 'VIOLATION_FOUND', 
                            disciplinary_action = 'APPLIED', )
                        ], ),
        )
        """

    def testResponseDataSROMemberDetails(self):
        """Test ResponseDataSROMemberDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_list_customer_email_out import ResponseDataListCustomerEmailOut

class TestResponseDataListCustomerEmailOut(unittest.TestCase):
    """ResponseDataListCustomerEmailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataListCustomerEmailOut:
        """Test ResponseDataListCustomerEmailOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataListCustomerEmailOut`
        """
        model = ResponseDataListCustomerEmailOut()
        if include_optional:
            return ResponseDataListCustomerEmailOut(
                data = [
                    sromaster.models.customer_email_out.CustomerEmailOut(
                        id = 56, 
                        label = '', 
                        email = '', 
                        is_primary = True, )
                    ]
            )
        else:
            return ResponseDataListCustomerEmailOut(
                data = [
                    sromaster.models.customer_email_out.CustomerEmailOut(
                        id = 56, 
                        label = '', 
                        email = '', 
                        is_primary = True, )
                    ],
        )
        """

    def testResponseDataListCustomerEmailOut(self):
        """Test ResponseDataListCustomerEmailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.4
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_sro_public import ResponseDataSROPublic

class TestResponseDataSROPublic(unittest.TestCase):
    """ResponseDataSROPublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataSROPublic:
        """Test ResponseDataSROPublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataSROPublic`
        """
        model = ResponseDataSROPublic()
        if include_optional:
            return ResponseDataSROPublic(
                data = sromaster.models.sro_public.SROPublic(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    name = '', 
                    reg_number = '', 
                    inn = 56, 
                    ogrn = 56, 
                    address = '', 
                    phone = '', 
                    email = '', 
                    website = '', 
                    members_count = 56, )
            )
        else:
            return ResponseDataSROPublic(
                data = sromaster.models.sro_public.SROPublic(
                    id = 56, 
                    registry = 'NOPRIZ', 
                    registry_id = 56, 
                    name = '', 
                    reg_number = '', 
                    inn = 56, 
                    ogrn = 56, 
                    address = '', 
                    phone = '', 
                    email = '', 
                    website = '', 
                    members_count = 56, ),
        )
        """

    def testResponseDataSROPublic(self):
        """Test ResponseDataSROPublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.page_sro_public_input import PageSROPublicInput

class TestPageSROPublicInput(unittest.TestCase):
    """PageSROPublicInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageSROPublicInput:
        """Test PageSROPublicInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageSROPublicInput`
        """
        model = PageSROPublicInput()
        if include_optional:
            return PageSROPublicInput(
                items = [
                    sromaster.models.sro_public.SROPublic(
                        id = 56, 
                        registry = 'NOPRIZ', 
                        registry_id = 56, 
                        name = '', 
                        reg_number = '', 
                        inn = 56, 
                        ogrn = 56, 
                        address = '', 
                        phone = '', 
                        email = '', 
                        website = '', 
                        status = 'ACTIVE', 
                        exclusion_reason = '', 
                        members_count = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return PageSROPublicInput(
                items = [
                    sromaster.models.sro_public.SROPublic(
                        id = 56, 
                        registry = 'NOPRIZ', 
                        registry_id = 56, 
                        name = '', 
                        reg_number = '', 
                        inn = 56, 
                        ogrn = 56, 
                        address = '', 
                        phone = '', 
                        email = '', 
                        website = '', 
                        status = 'ACTIVE', 
                        exclusion_reason = '', 
                        members_count = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56,
        )
        """

    def testPageSROPublicInput(self):
        """Test PageSROPublicInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from sromaster.models.email_search_status import EmailSearchStatus
from sromaster.models.insurance_premium import InsurancePremium
from sromaster.models.insured_sum import InsuredSum
from sromaster.models.invoice_status import InvoiceStatus
from sromaster.models.mailing_result import MailingResult
from sromaster.models.mailing_status import MailingStatus
from sromaster.models.message_status import MessageStatus
from typing import Optional, Set
from typing_extensions import Self

class IMMailingUpdate(BaseModel):
    """
    IMMailingUpdate
    """ # noqa: E501
    dispatch_at: Optional[datetime] = None
    email_search_status: Optional[EmailSearchStatus] = None
    invoice_status: Optional[InvoiceStatus] = None
    status: Optional[MailingStatus] = None
    result: Optional[MailingResult] = None
    insured_sum: Optional[InsuredSum] = None
    insurance_premium: Optional[InsurancePremium] = None
    im_sro_id: Optional[StrictInt] = None
    message_status: Optional[MessageStatus] = None
    __properties: ClassVar[List[str]] = ["dispatch_at", "email_search_status", "invoice_status", "status", "result", "insured_sum", "insurance_premium", "im_sro_id", "message_status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IMMailingUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of insured_sum
        if self.insured_sum:
            _dict['insured_sum'] = self.insured_sum.to_dict()
        # override the default output from pydantic by calling `to_dict()` of insurance_premium
        if self.insurance_premium:
            _dict['insurance_premium'] = self.insurance_premium.to_dict()
        # set to None if dispatch_at (nullable) is None
        # and model_fields_set contains the field
        if self.dispatch_at is None and "dispatch_at" in self.model_fields_set:
            _dict['dispatch_at'] = None

        # set to None if email_search_status (nullable) is None
        # and model_fields_set contains the field
        if self.email_search_status is None and "email_search_status" in self.model_fields_set:
            _dict['email_search_status'] = None

        # set to None if invoice_status (nullable) is None
        # and model_fields_set contains the field
        if self.invoice_status is None and "invoice_status" in self.model_fields_set:
            _dict['invoice_status'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if result (nullable) is None
        # and model_fields_set contains the field
        if self.result is None and "result" in self.model_fields_set:
            _dict['result'] = None

        # set to None if insured_sum (nullable) is None
        # and model_fields_set contains the field
        if self.insured_sum is None and "insured_sum" in self.model_fields_set:
            _dict['insured_sum'] = None

        # set to None if insurance_premium (nullable) is None
        # and model_fields_set contains the field
        if self.insurance_premium is None and "insurance_premium" in self.model_fields_set:
            _dict['insurance_premium'] = None

        # set to None if im_sro_id (nullable) is None
        # and model_fields_set contains the field
        if self.im_sro_id is None and "im_sro_id" in self.model_fields_set:
            _dict['im_sro_id'] = None

        # set to None if message_status (nullable) is None
        # and model_fields_set contains the field
        if self.message_status is None and "message_status" in self.model_fields_set:
            _dict['message_status'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IMMailingUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "dispatch_at": obj.get("dispatch_at"),
            "email_search_status": obj.get("email_search_status"),
            "invoice_status": obj.get("invoice_status"),
            "status": obj.get("status"),
            "result": obj.get("result"),
            "insured_sum": InsuredSum.from_dict(obj["insured_sum"]) if obj.get("insured_sum") is not None else None,
            "insurance_premium": InsurancePremium.from_dict(obj["insurance_premium"]) if obj.get("insurance_premium") is not None else None,
            "im_sro_id": obj.get("im_sro_id"),
            "message_status": obj.get("message_status")
        })
        return _obj





# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from sromaster.models.tariff_entry import TariffEntry
from typing import Optional, Set
from typing_extensions import Self

class IMSroUpsertRequest(BaseModel):
    """
    IMSroUpsertRequest
    """ # noqa: E501
    tariffs: Optional[Dict[str, TariffEntry]] = None
    description: Optional[StrictStr] = None
    pre_expiry_days: Optional[Annotated[int, Field(le=3650, strict=True, ge=0)]] = None
    insurance_regulations: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["tariffs", "description", "pre_expiry_days", "insurance_regulations"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IMSroUpsertRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in tariffs (dict)
        _field_dict = {}
        if self.tariffs:
            for _key_tariffs in self.tariffs:
                if self.tariffs[_key_tariffs]:
                    _field_dict[_key_tariffs] = self.tariffs[_key_tariffs].to_dict()
            _dict['tariffs'] = _field_dict
        # set to None if tariffs (nullable) is None
        # and model_fields_set contains the field
        if self.tariffs is None and "tariffs" in self.model_fields_set:
            _dict['tariffs'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if pre_expiry_days (nullable) is None
        # and model_fields_set contains the field
        if self.pre_expiry_days is None and "pre_expiry_days" in self.model_fields_set:
            _dict['pre_expiry_days'] = None

        # set to None if insurance_regulations (nullable) is None
        # and model_fields_set contains the field
        if self.insurance_regulations is None and "insurance_regulations" in self.model_fields_set:
            _dict['insurance_regulations'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IMSroUpsertRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "tariffs": dict(
                (_k, TariffEntry.from_dict(_v))
                for _k, _v in obj["tariffs"].items()
            )
            if obj.get("tariffs") is not None
            else None,
            "description": obj.get("description"),
            "pre_expiry_days": obj.get("pre_expiry_days"),
            "insurance_regulations": obj.get("insurance_regulations")
        })
        return _obj





# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.2
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.check_type import CheckType

class TestCheckType(unittest.TestCase):
    """CheckType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCheckType(self):
        """Test CheckType"""
        # inst = CheckType()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.src_models_sro_member_registry import SrcModelsSroMemberRegistry

class TestSrcModelsSroMemberRegistry(unittest.TestCase):
    """SrcModelsSroMemberRegistry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSrcModelsSroMemberRegistry(self):
        """Test SrcModelsSroMemberRegistry"""
        # inst = SrcModelsSroMemberRegistry()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.im_insurers_api import ImInsurersApi


class TestImInsurersApi(unittest.IsolatedAsyncioTestCase):
    """ImInsurersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ImInsurersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_im_insurer_im_insurers_post(self) -> None:
        """Test case for create_im_insurer_im_insurers_post

        Create Im Insurer
        """
        pass

    async def test_delete_im_insurer_im_insurers_insurer_id_delete(self) -> None:
        """Test case for delete_im_insurer_im_insurers_insurer_id_delete

        Delete Im Insurer
        """
        pass

    async def test_get_im_insurer_im_insurers_insurer_id_get(self) -> None:
        """Test case for get_im_insurer_im_insurers_insurer_id_get

        Get Im Insurer
        """
        pass

    async def test_list_im_insurers_im_insurers_get(self) -> None:
        """Test case for list_im_insurers_im_insurers_get

        List Im Insurers
        """
        pass

    async def test_update_im_insurer_im_insurers_insurer_id_patch(self) -> None:
        """Test case for update_im_insurer_im_insurers_insurer_id_patch

        Update Im Insurer
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.sro_member_upsert_request import SROMemberUpsertRequest


class TestSROMemberUpsertRequest(unittest.TestCase):
    """SROMemberUpsertRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SROMemberUpsertRequest:
        """Test SROMemberUpsertRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SROMemberUpsertRequest`
        """
        model = SROMemberUpsertRequest()
        if include_optional:
            return SROMemberUpsertRequest(
                registry = 'NOPRIZ',
                registry_id = 56,
                sro_registry_id = 56,
                organization = sromaster.models.organization_schema.OrganizationSchema(
                    inn = 56, 
                    ogrn = 56, 
                    legal_form = 'LEGAL_ENTITY', 
                    name_full = '', 
                    name_short = '', 
                    address = '', 
                    director_name = '', 
                    registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                registration_number = '',
                member_status = 'ACTIVE',
                included_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                excluded_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                exclusion_reason = '',
                accordance_status = 'ACCORDANT',
                is_simple = True,
                is_extremely_dangerous = True,
                is_nuclear = True,
                is_odo = True,
                compensation_fund_fee_vv = 56,
                compensation_fund_fee_odo = 56,
                responsibility_level_vv = '',
                responsibility_level_odo = '',
                registry_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                insurances = [
                    sromaster.models.insurance_upsert_request.InsuranceUpsertRequest(
                        registry_id = 56, 
                        insurer = '', 
                        address = '', 
                        insurance_object = '', 
                        amount = '', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                checks = [
                    sromaster.models.check_upsert_request.CheckUpsertRequest(
                        registry_id = 56, 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        state = 'PLANED', 
                        result = 'VIOLATION_FOUND', 
                        disciplinary_action = 'APPLIED', )
                    ]
            )
        else:
            return SROMemberUpsertRequest(
                registry = 'NOPRIZ',
                registry_id = 56,
                sro_registry_id = 56,
                organization = sromaster.models.organization_schema.OrganizationSchema(
                    inn = 56, 
                    ogrn = 56, 
                    legal_form = 'LEGAL_ENTITY', 
                    name_full = '', 
                    name_short = '', 
                    address = '', 
                    director_name = '', 
                    registered_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testSROMemberUpsertRequest(self):
        """Test SROMemberUpsertRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.9
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.page_im_sro_public_output import PageIMSroPublicOutput

class TestPageIMSroPublicOutput(unittest.TestCase):
    """PageIMSroPublicOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageIMSroPublicOutput:
        """Test PageIMSroPublicOutput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageIMSroPublicOutput`
        """
        model = PageIMSroPublicOutput()
        if include_optional:
            return PageIMSroPublicOutput(
                items = [
                    sromaster.models.im_sro_public.IMSroPublic(
                        sro_id = 56, 
                        tariffs = {
                            'key' : { }
                            }, 
                        description = '', 
                        pre_expiry_days = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return PageIMSroPublicOutput(
                items = [
                    sromaster.models.im_sro_public.IMSroPublic(
                        sro_id = 56, 
                        tariffs = {
                            'key' : { }
                            }, 
                        description = '', 
                        pre_expiry_days = 56, )
                    ],
                page = 56,
                per_page = 56,
                total = 56,
                total_pages = 56,
        )
        """

    def testPageIMSroPublicOutput(self):
        """Test PageIMSroPublicOutput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.22"

# Define package exports
__all__ = [
    "CustomersApi",
    "ImInsurersApi",
    "ImMailingApi",
    "ImMailingInvoicesApi",
    "ImSrosApi",
    "InsurancesApi",
    "OrganizationEmailsApi",
    "OrganizationsApi",
    "ParserApi",
    "ParserWriteApi",
    "UsersApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AccordanceStatus",
    "CheckDisciplinaryAction",
    "CheckOut",
    "CheckResult",
    "CheckType",
    "CheckUpsertRequest",
    "CustomerCreate",
    "CustomerEmailIn",
    "CustomerEmailOut",
    "CustomerOut",
    "CustomerPhoneIn",
    "CustomerPhoneOut",
    "CustomerStatus",
    "CustomerUpdate",
    "EmailSearchStatus",
    "HTTPValidationError",
    "IMInsurerCreate",
    "IMInsurerOut",
    "IMInsurerUpdate",
    "IMMailingCreate",
    "IMMailingInvoiceOut",
    "IMMailingInvoiceSummary",
    "IMMailingOutInput",
    "IMMailingOutOutput",
    "IMMailingUpdate",
    "IMSroPublic",
    "IMSroUpsertRequest",
    "InsuranceOut",
    "InsurancePremium",
    "InsuranceUpsertRequest",
    "InsuredSum",
    "InvoiceFinalizeRequest",
    "InvoiceStatus",
    "InvoiceUploadUrlRequest",
    "InvoiceUploadUrlResponse",
    "LegalForm",
    "MailingResult",
    "MailingStatus",
    "MemberStatus",
    "MessageStatus",
    "OrganizationCreate",
    "OrganizationEmailCreate",
    "OrganizationEmailOut",
    "OrganizationEmailUpdate",
    "OrganizationOut",
    "OrganizationPublic",
    "OrganizationSchema",
    "OrganizationUpdate",
    "PageCustomerOutInput",
    "PageCustomerOutOutput",
    "PageIMInsurerOutInput",
    "PageIMInsurerOutOutput",
    "PageIMMailingInvoiceOut",
    "PageIMMailingOutInput",
    "PageIMMailingOutOutput",
    "PageIMSroPublicInput",
    "PageIMSroPublicOutput",
    "PageInsuranceOut",
    "PageOrganizationEmailOut",
    "PageOrganizationOutInput",
    "PageOrganizationOutOutput",
    "PageSROMemberListItemInput",
    "PageSROMemberListItemOutput",
    "PageSROPublicInput",
    "PageSROPublicOutput",
    "ParticipationStatus",
    "ResponseDataCustomerEmailOut",
    "ResponseDataCustomerOut",
    "ResponseDataCustomerPhoneOut",
    "ResponseDataIMInsurerOut",
    "ResponseDataIMMailingInvoiceOut",
    "ResponseDataIMMailingOut",
    "ResponseDataIMSroPublic",
    "ResponseDataInsuranceOut",
    "ResponseDataInvoiceUploadUrlResponse",
    "ResponseDataListCustomerEmailOut",
    "ResponseDataListCustomerPhoneOut",
    "ResponseDataListIMMailingOut",
    "ResponseDataListOrganizationEmailOut",
    "ResponseDataOrganizationEmailOut",
    "ResponseDataOrganizationOut",
    "ResponseDataPageCustomerOut",
    "ResponseDataPageIMInsurerOut",
    "ResponseDataPageIMMailingInvoiceOut",
    "ResponseDataPageIMMailingOut",
    "ResponseDataPageIMSroPublic",
    "ResponseDataPageInsuranceOut",
    "ResponseDataPageOrganizationEmailOut",
    "ResponseDataPageOrganizationOut",
    "ResponseDataPageSROMemberListItem",
    "ResponseDataPageSROPublic",
    "ResponseDataSROMemberDetails",
    "ResponseDataSROPublic",
    "ResponseDataStr",
    "ResponseDataUserResponse",
    "ResponsibilityLevel",
    "RightStatus",
    "SROMemberDetailsInput",
    "SROMemberDetailsOutput",
    "SROMemberListItemInput",
    "SROMemberListItemOutput",
    "SROMemberUpsertRequest",
    "SROPublic",
    "SROShort",
    "SROStatus",
    "SROUpsertRequest",
    "SourceRegistry",
    "SrcModelsSroMemberRegistry",
    "TariffEntry",
    "UserResponse",
    "ValidationError",
    "ValidationErrorLocInner",
]

# import apis into sdk package
from sromaster.api.customers_api import CustomersApi as CustomersApi
from sromaster.api.im_insurers_api import ImInsurersApi as ImInsurersApi
from sromaster.api.im_mailing_api import ImMailingApi as ImMailingApi
from sromaster.api.im_mailing_invoices_api import ImMailingInvoicesApi as ImMailingInvoicesApi
from sromaster.api.im_sros_api import ImSrosApi as ImSrosApi
from sromaster.api.insurances_api import InsurancesApi as InsurancesApi
from sromaster.api.organization_emails_api import OrganizationEmailsApi as OrganizationEmailsApi
from sromaster.api.organizations_api import OrganizationsApi as OrganizationsApi
from sromaster.api.parser_api import ParserApi as ParserApi
from sromaster.api.parser_write_api import ParserWriteApi as ParserWriteApi
from sromaster.api.users_api import UsersApi as UsersApi

# import ApiClient
from sromaster.api_response import ApiResponse as ApiResponse
from sromaster.api_client import ApiClient as ApiClient
from sromaster.configuration import Configuration as Configuration
from sromaster.exceptions import OpenApiException as OpenApiException
from sromaster.exceptions import ApiTypeError as ApiTypeError
from sromaster.exceptions import ApiValueError as ApiValueError
from sromaster.exceptions import ApiKeyError as ApiKeyError
from sromaster.exceptions import ApiAttributeError as ApiAttributeError
from sromaster.exceptions import ApiException as ApiException

# import models into sdk package
from sromaster.models.accordance_status import AccordanceStatus as AccordanceStatus
from sromaster.models.check_disciplinary_action import CheckDisciplinaryAction as CheckDisciplinaryAction
from sromaster.models.check_out import CheckOut as CheckOut
from sromaster.models.check_result import CheckResult as CheckResult
from sromaster.models.check_type import CheckType as CheckType
from sromaster.models.check_upsert_request import CheckUpsertRequest as CheckUpsertRequest
from sromaster.models.customer_create import CustomerCreate as CustomerCreate
from sromaster.models.customer_email_in import CustomerEmailIn as CustomerEmailIn
from sromaster.models.customer_email_out import CustomerEmailOut as CustomerEmailOut
from sromaster.models.customer_out import CustomerOut as CustomerOut
from sromaster.models.customer_phone_in import CustomerPhoneIn as CustomerPhoneIn
from sromaster.models.customer_phone_out import CustomerPhoneOut as CustomerPhoneOut
from sromaster.models.customer_status import CustomerStatus as CustomerStatus
from sromaster.models.customer_update import CustomerUpdate as CustomerUpdate
from sromaster.models.email_search_status import EmailSearchStatus as EmailSearchStatus
from sromaster.models.http_validation_error import HTTPValidationError as HTTPValidationError
from sromaster.models.im_insurer_create import IMInsurerCreate as IMInsurerCreate
from sromaster.models.im_insurer_out import IMInsurerOut as IMInsurerOut
from sromaster.models.im_insurer_update import IMInsurerUpdate as IMInsurerUpdate
from sromaster.models.im_mailing_create import IMMailingCreate as IMMailingCreate
from sromaster.models.im_mailing_invoice_out import IMMailingInvoiceOut as IMMailingInvoiceOut
from sromaster.models.im_mailing_invoice_summary import IMMailingInvoiceSummary as IMMailingInvoiceSummary
from sromaster.models.im_mailing_out_input import IMMailingOutInput as IMMailingOutInput
from sromaster.models.im_mailing_out_output import IMMailingOutOutput as IMMailingOutOutput
from sromaster.models.im_mailing_update import IMMailingUpdate as IMMailingUpdate
from sromaster.models.im_sro_public import IMSroPublic as IMSroPublic
from sromaster.models.im_sro_upsert_request import IMSroUpsertRequest as IMSroUpsertRequest
from sromaster.models.insurance_out import InsuranceOut as InsuranceOut
from sromaster.models.insurance_premium import InsurancePremium as InsurancePremium
from sromaster.models.insurance_upsert_request import InsuranceUpsertRequest as InsuranceUpsertRequest
from sromaster.models.insured_sum import InsuredSum as InsuredSum
from sromaster.models.invoice_finalize_request import InvoiceFinalizeRequest as InvoiceFinalizeRequest
from sromaster.models.invoice_status import InvoiceStatus as InvoiceStatus
from sromaster.models.invoice_upload_url_request import InvoiceUploadUrlRequest as InvoiceUploadUrlRequest
from sromaster.models.invoice_upload_url_response import InvoiceUploadUrlResponse as InvoiceUploadUrlResponse
from sromaster.models.legal_form import LegalForm as LegalForm
from sromaster.models.mailing_result import MailingResult as MailingResult
from sromaster.models.mailing_status import MailingStatus as MailingStatus
from sromaster.models.member_status import MemberStatus as MemberStatus
from sromaster.models.message_status import MessageStatus as MessageStatus
from sromaster.models.organization_create import OrganizationCreate as OrganizationCreate
from sromaster.models.organization_email_create import OrganizationEmailCreate as OrganizationEmailCreate
from sromaster.models.organization_email_out import OrganizationEmailOut as OrganizationEmailOut
from sromaster.models.organization_email_update import OrganizationEmailUpdate as OrganizationEmailUpdate
from sromaster.models.organization_out import OrganizationOut as OrganizationOut
from sromaster.models.organization_public import OrganizationPublic as OrganizationPublic
from sromaster.models.organization_schema import OrganizationSchema as OrganizationSchema
from sromaster.models.organization_update import OrganizationUpdate as OrganizationUpdate
from sromaster.models.page_customer_out_input import PageCustomerOutInput as PageCustomerOutInput
from sromaster.models.page_customer_out_output import PageCustomerOutOutput as PageCustomerOutOutput
from sromaster.models.page_im_insurer_out_input import PageIMInsurerOutInput as PageIMInsurerOutInput
from sromaster.models.page_im_insurer_out_output import PageIMInsurerOutOutput as PageIMInsurerOutOutput
from sromaster.models.page_im_mailing_invoice_out import PageIMMailingInvoiceOut as PageIMMailingInvoiceOut
from sromaster.models.page_im_mailing_out_input import PageIMMailingOutInput as PageIMMailingOutInput
from sromaster.models.page_im_mailing_out_output import PageIMMailingOutOutput as PageIMMailingOutOutput
from sromaster.models.page_im_sro_public_input import PageIMSroPublicInput as PageIMSroPublicInput
from sromaster.models.page_im_sro_public_output import PageIMSroPublicOutput as PageIMSroPublicOutput
from sromaster.models.page_insurance_out import PageInsuranceOut as PageInsuranceOut
from sromaster.models.page_organization_email_out import PageOrganizationEmailOut as PageOrganizationEmailOut
from sromaster.models.page_organization_out_input import PageOrganizationOutInput as PageOrganizationOutInput
from sromaster.models.page_organization_out_output import PageOrganizationOutOutput as PageOrganizationOutOutput
from sromaster.models.page_sro_member_list_item_input import PageSROMemberListItemInput as PageSROMemberListItemInput
from sromaster.models.page_sro_member_list_item_output import PageSROMemberListItemOutput as PageSROMemberListItemOutput
from sromaster.models.page_sro_public_input import PageSROPublicInput as PageSROPublicInput
from sromaster.models.page_sro_public_output import PageSROPublicOutput as PageSROPublicOutput
from sromaster.models.participation_status import ParticipationStatus as ParticipationStatus
from sromaster.models.response_data_customer_email_out import ResponseDataCustomerEmailOut as ResponseDataCustomerEmailOut
from sromaster.models.response_data_customer_out import ResponseDataCustomerOut as ResponseDataCustomerOut
from sromaster.models.response_data_customer_phone_out import ResponseDataCustomerPhoneOut as ResponseDataCustomerPhoneOut
from sromaster.models.response_data_im_insurer_out import ResponseDataIMInsurerOut as ResponseDataIMInsurerOut
from sromaster.models.response_data_im_mailing_invoice_out import ResponseDataIMMailingInvoiceOut as ResponseDataIMMailingInvoiceOut
from sromaster.models.response_data_im_mailing_out import ResponseDataIMMailingOut as ResponseDataIMMailingOut
from sromaster.models.response_data_im_sro_public import ResponseDataIMSroPublic as ResponseDataIMSroPublic
from sromaster.models.response_data_insurance_out import ResponseDataInsuranceOut as ResponseDataInsuranceOut
from sromaster.models.response_data_invoice_upload_url_response import ResponseDataInvoiceUploadUrlResponse as ResponseDataInvoiceUploadUrlResponse
from sromaster.models.response_data_list_customer_email_out import ResponseDataListCustomerEmailOut as ResponseDataListCustomerEmailOut
from sromaster.models.response_data_list_customer_phone_out import ResponseDataListCustomerPhoneOut as ResponseDataListCustomerPhoneOut
from sromaster.models.response_data_list_im_mailing_out import ResponseDataListIMMailingOut as ResponseDataListIMMailingOut
from sromaster.models.response_data_list_organization_email_out import ResponseDataListOrganizationEmailOut as ResponseDataListOrganizationEmailOut
from sromaster.models.response_data_organization_email_out import ResponseDataOrganizationEmailOut as ResponseDataOrganizationEmailOut
from sromaster.models.response_data_organization_out import ResponseDataOrganizationOut as ResponseDataOrganizationOut
from sromaster.models.response_data_page_customer_out import ResponseDataPageCustomerOut as ResponseDataPageCustomerOut
from sromaster.models.response_data_page_im_insurer_out import ResponseDataPageIMInsurerOut as ResponseDataPageIMInsurerOut
from sromaster.models.response_data_page_im_mailing_invoice_out import ResponseDataPageIMMailingInvoiceOut as ResponseDataPageIMMailingInvoiceOut
from sromaster.models.response_data_page_im_mailing_out import ResponseDataPageIMMailingOut as ResponseDataPageIMMailingOut
from sromaster.models.response_data_page_im_sro_public import ResponseDataPageIMSroPublic as ResponseDataPageIMSroPublic
from sromaster.models.response_data_page_insurance_out import ResponseDataPageInsuranceOut as ResponseDataPageInsuranceOut
from sromaster.models.response_data_page_organization_email_out import ResponseDataPageOrganizationEmailOut as ResponseDataPageOrganizationEmailOut
from sromaster.models.response_data_page_organization_out import ResponseDataPageOrganizationOut as ResponseDataPageOrganizationOut
from sromaster.models.response_data_page_sro_member_list_item import ResponseDataPageSROMemberListItem as ResponseDataPageSROMemberListItem
from sromaster.models.response_data_page_sro_public import ResponseDataPageSROPublic as ResponseDataPageSROPublic
from sromaster.models.response_data_sro_member_details import ResponseDataSROMemberDetails as ResponseDataSROMemberDetails
from sromaster.models.response_data_sro_public import ResponseDataSROPublic as ResponseDataSROPublic
from sromaster.models.response_data_str import ResponseDataStr as ResponseDataStr
from sromaster.models.response_data_user_response import ResponseDataUserResponse as ResponseDataUserResponse
from sromaster.models.responsibility_level import ResponsibilityLevel as ResponsibilityLevel
from sromaster.models.right_status import RightStatus as RightStatus
from sromaster.models.sro_member_details_input import SROMemberDetailsInput as SROMemberDetailsInput
from sromaster.models.sro_member_details_output import SROMemberDetailsOutput as SROMemberDetailsOutput
from sromaster.models.sro_member_list_item_input import SROMemberListItemInput as SROMemberListItemInput
from sromaster.models.sro_member_list_item_output import SROMemberListItemOutput as SROMemberListItemOutput
from sromaster.models.sro_member_upsert_request import SROMemberUpsertRequest as SROMemberUpsertRequest
from sromaster.models.sro_public import SROPublic as SROPublic
from sromaster.models.sro_short import SROShort as SROShort
from sromaster.models.sro_status import SROStatus as SROStatus
from sromaster.models.sro_upsert_request import SROUpsertRequest as SROUpsertRequest
from sromaster.models.source_registry import SourceRegistry as SourceRegistry
from sromaster.models.src_models_sro_member_registry import SrcModelsSroMemberRegistry as SrcModelsSroMemberRegistry
from sromaster.models.tariff_entry import TariffEntry as TariffEntry
from sromaster.models.user_response import UserResponse as UserResponse
from sromaster.models.validation_error import ValidationError as ValidationError
from sromaster.models.validation_error_loc_inner import ValidationErrorLocInner as ValidationErrorLocInner



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sromaster.models.customer_email_out import CustomerEmailOut
from sromaster.models.customer_phone_out import CustomerPhoneOut
from sromaster.models.customer_status import CustomerStatus
from typing import Optional, Set
from typing_extensions import Self

class CustomerOut(BaseModel):
    """
    CustomerOut
    """ # noqa: E501
    id: StrictInt
    name: StrictStr
    inn: Optional[StrictStr]
    ogrn: Optional[StrictStr]
    address: Optional[StrictStr]
    status: CustomerStatus
    phones: Optional[List[CustomerPhoneOut]] = None
    emails: Optional[List[CustomerEmailOut]] = None
    __properties: ClassVar[List[str]] = ["id", "name", "inn", "ogrn", "address", "status", "phones", "emails"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomerOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in phones (list)
        _items = []
        if self.phones:
            for _item_phones in self.phones:
                if _item_phones:
                    _items.append(_item_phones.to_dict())
            _dict['phones'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in emails (list)
        _items = []
        if self.emails:
            for _item_emails in self.emails:
                if _item_emails:
                    _items.append(_item_emails.to_dict())
            _dict['emails'] = _items
        # set to None if inn (nullable) is None
        # and model_fields_set contains the field
        if self.inn is None and "inn" in self.model_fields_set:
            _dict['inn'] = None

        # set to None if ogrn (nullable) is None
        # and model_fields_set contains the field
        if self.ogrn is None and "ogrn" in self.model_fields_set:
            _dict['ogrn'] = None

        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict['address'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomerOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "inn": obj.get("inn"),
            "ogrn": obj.get("ogrn"),
            "address": obj.get("address"),
            "status": obj.get("status"),
            "phones": [CustomerPhoneOut.from_dict(_item) for _item in obj["phones"]] if obj.get("phones") is not None else None,
            "emails": [CustomerEmailOut.from_dict(_item) for _item in obj["emails"]] if obj.get("emails") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.8
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.customers_api import CustomersApi


class TestCustomersApi(unittest.IsolatedAsyncioTestCase):
    """CustomersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CustomersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_customer_email_customers_customer_id_emails_post(self) -> None:
        """Test case for add_customer_email_customers_customer_id_emails_post

        Add Customer Email
        """
        pass

    async def test_add_customer_phone_customers_customer_id_phones_post(self) -> None:
        """Test case for add_customer_phone_customers_customer_id_phones_post

        Add Customer Phone
        """
        pass

    async def test_create_customer_customers_post(self) -> None:
        """Test case for create_customer_customers_post

        Create Customer
        """
        pass

    async def test_delete_customer_customers_customer_id_delete(self) -> None:
        """Test case for delete_customer_customers_customer_id_delete

        Delete Customer
        """
        pass

    async def test_delete_customer_email_customers_customer_id_emails_email_id_delete(self) -> None:
        """Test case for delete_customer_email_customers_customer_id_emails_email_id_delete

        Delete Customer Email
        """
        pass

    async def test_delete_customer_phone_customers_customer_id_phones_phone_id_delete(self) -> None:
        """Test case for delete_customer_phone_customers_customer_id_phones_phone_id_delete

        Delete Customer Phone
        """
        pass

    async def test_get_customer_customers_customer_id_get(self) -> None:
        """Test case for get_customer_customers_customer_id_get

        Get Customer
        """
        pass

    async def test_list_customer_emails_customers_customer_id_emails_get(self) -> None:
        """Test case for list_customer_emails_customers_customer_id_emails_get

        List Customer Emails
        """
        pass

    async def test_list_customer_phones_customers_customer_id_phones_get(self) -> None:
        """Test case for list_customer_phones_customers_customer_id_phones_get

        List Customer Phones
        """
        pass

    async def test_list_customers_customers_get(self) -> None:
        """Test case for list_customers_customers_get

        List Customers
        """
        pass

    async def test_update_customer_customers_customer_id_patch(self) -> None:
        """Test case for update_customer_customers_customer_id_patch

        Update Customer
        """
        pass

    async def test_update_customer_email_customers_customer_id_emails_email_id_patch(self) -> None:
        """Test case for update_customer_email_customers_customer_id_emails_email_id_patch

        Update Customer Email
        """
        pass

    async def test_update_customer_phone_customers_customer_id_phones_phone_id_patch(self) -> None:
        """Test case for update_customer_phone_customers_customer_id_phones_phone_id_patch

        Update Customer Phone
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.10
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.models.response_data_im_email_out import ResponseDataIMEmailOut

class TestResponseDataIMEmailOut(unittest.TestCase):
    """ResponseDataIMEmailOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseDataIMEmailOut:
        """Test ResponseDataIMEmailOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseDataIMEmailOut`
        """
        model = ResponseDataIMEmailOut()
        if include_optional:
            return ResponseDataIMEmailOut(
                data = sromaster.models.im_email_out.IMEmailOut(
                    id = 56, 
                    organization_id = 56, 
                    email = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return ResponseDataIMEmailOut(
                data = sromaster.models.im_email_out.IMEmailOut(
                    id = 56, 
                    organization_id = 56, 
                    email = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testResponseDataIMEmailOut(self):
        """Test ResponseDataIMEmailOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.1
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.accordance_status import AccordanceStatus
from openapi_client.models.check_disciplinary_action import CheckDisciplinaryAction
from openapi_client.models.check_result import CheckResult
from openapi_client.models.check_state import CheckState
from openapi_client.models.check_upsert_request import CheckUpsertRequest
from openapi_client.models.http_validation_error import HTTPValidationError
from openapi_client.models.insurance_upsert_request import InsuranceUpsertRequest
from openapi_client.models.legal_form import LegalForm
from openapi_client.models.member_status import MemberStatus
from openapi_client.models.organization_schema import OrganizationSchema
from openapi_client.models.registry import Registry
from openapi_client.models.response_data_user_response import ResponseDataUserResponse
from openapi_client.models.sro_member_upsert_request import SROMemberUpsertRequest
from openapi_client.models.sro_upsert_request import SROUpsertRequest
from openapi_client.models.user_response import UserResponse
from openapi_client.models.validation_error import ValidationError
from openapi_client.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.11
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sromaster.api.organization_emails_api import OrganizationEmailsApi


class TestOrganizationEmailsApi(unittest.IsolatedAsyncioTestCase):
    """OrganizationEmailsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OrganizationEmailsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_org_email_organization_emails_post(self) -> None:
        """Test case for create_org_email_organization_emails_post

        Create Org Email
        """
        pass

    async def test_delete_org_email_organization_emails_item_id_delete(self) -> None:
        """Test case for delete_org_email_organization_emails_item_id_delete

        Delete Org Email
        """
        pass

    async def test_get_org_email_organization_emails_item_id_get(self) -> None:
        """Test case for get_org_email_organization_emails_item_id_get

        Get Org Email
        """
        pass

    async def test_list_org_emails_organization_emails_get(self) -> None:
        """Test case for list_org_emails_organization_emails_get

        List Org Emails
        """
        pass

    async def test_update_org_email_organization_emails_item_id_patch(self) -> None:
        """Test case for update_org_email_organization_emails_item_id_patch

        Update Org Email
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from sromaster.models.email_search_status import EmailSearchStatus
from sromaster.models.im_mailing_create import IMMailingCreate
from sromaster.models.im_mailing_update import IMMailingUpdate
from sromaster.models.invoice_status import InvoiceStatus
from sromaster.models.mailing_result import MailingResult
from sromaster.models.mailing_status import MailingStatus
from sromaster.models.response_data_im_mailing_out import ResponseDataIMMailingOut
from sromaster.models.response_data_list_im_mailing_out import ResponseDataListIMMailingOut
from sromaster.models.response_data_page_im_mailing_out import ResponseDataPageIMMailingOut

from sromaster.api_client import ApiClient, RequestSerialized
from sromaster.api_response import ApiResponse
from sromaster.rest import RESTResponseType


class ImMailingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def create_item_im_mailing_post(
        self,
        im_mailing_create: IMMailingCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResponseDataIMMailingOut:
        """Create Item


        :param im_mailing_create: (required)
        :type im_mailing_create: IMMailingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_item_im_mailing_post_serialize(
            im_mailing_create=im_mailing_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def create_item_im_mailing_post_with_http_info(
        self,
        im_mailing_create: IMMailingCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResponseDataIMMailingOut]:
        """Create Item


        :param im_mailing_create: (required)
        :type im_mailing_create: IMMailingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_item_im_mailing_post_serialize(
            im_mailing_create=im_mailing_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def create_item_im_mailing_post_without_preload_content(
        self,
        im_mailing_create: IMMailingCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Item


        :param im_mailing_create: (required)
        :type im_mailing_create: IMMailingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_item_im_mailing_post_serialize(
            im_mailing_create=im_mailing_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_item_im_mailing_post_serialize(
        self,
        im_mailing_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if im_mailing_create is not None:
            _body_params = im_mailing_create


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/im-mailing',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def delete_item_im_mailing_item_id_delete(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_item_im_mailing_item_id_delete_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def delete_item_im_mailing_item_id_delete_with_http_info(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_item_im_mailing_item_id_delete_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def delete_item_im_mailing_item_id_delete_without_preload_content(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_item_im_mailing_item_id_delete_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_item_im_mailing_item_id_delete_serialize(
        self,
        item_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if item_id is not None:
            _path_params['item_id'] = item_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/im-mailing/{item_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def generate_items_im_mailing_generate_post(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResponseDataListIMMailingOut:
        """Generate Items


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_items_im_mailing_generate_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataListIMMailingOut",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def generate_items_im_mailing_generate_post_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResponseDataListIMMailingOut]:
        """Generate Items


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_items_im_mailing_generate_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataListIMMailingOut",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def generate_items_im_mailing_generate_post_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Generate Items


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_items_im_mailing_generate_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataListIMMailingOut",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _generate_items_im_mailing_generate_post_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/im-mailing/generate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def get_item_im_mailing_item_id_get(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResponseDataIMMailingOut:
        """Get Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_item_im_mailing_item_id_get_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def get_item_im_mailing_item_id_get_with_http_info(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResponseDataIMMailingOut]:
        """Get Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_item_im_mailing_item_id_get_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def get_item_im_mailing_item_id_get_without_preload_content(
        self,
        item_id: StrictInt,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Item


        :param item_id: (required)
        :type item_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_item_im_mailing_item_id_get_serialize(
            item_id=item_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_item_im_mailing_item_id_get_serialize(
        self,
        item_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if item_id is not None:
            _path_params['item_id'] = item_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/im-mailing/{item_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def list_items_im_mailing_get(
        self,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (1-based)")] = None,
        per_page: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Items per page (max 100)")] = None,
        include_deleted: Annotated[Optional[StrictBool], Field(description="Include soft-deleted")] = None,
        include: Annotated[Optional[StrictStr], Field(description="Comma-separated: organization,insurance,insurer,invoice,sro")] = None,
        im_insurer_id: Optional[StrictInt] = None,
        has_invoice: Optional[StrictBool] = None,
        email_search_status: Optional[EmailSearchStatus] = None,
        invoice_status: Optional[InvoiceStatus] = None,
        status: Optional[MailingStatus] = None,
        result: Optional[MailingResult] = None,
        dispatch_at_from: Optional[StrictStr] = None,
        dispatch_at_to: Optional[StrictStr] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="id|dispatch_at")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="asc|desc")] = None,
        all: Annotated[Optional[StrictBool], Field(description="Return all items without pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResponseDataPageIMMailingOut:
        """List Items


        :param page: Page number (1-based)
        :type page: int
        :param per_page: Items per page (max 100)
        :type per_page: int
        :param include_deleted: Include soft-deleted
        :type include_deleted: bool
        :param include: Comma-separated: organization,insurance,insurer,invoice,sro
        :type include: str
        :param im_insurer_id:
        :type im_insurer_id: int
        :param has_invoice:
        :type has_invoice: bool
        :param email_search_status:
        :type email_search_status: EmailSearchStatus
        :param invoice_status:
        :type invoice_status: InvoiceStatus
        :param status:
        :type status: MailingStatus
        :param result:
        :type result: MailingResult
        :param dispatch_at_from:
        :type dispatch_at_from: str
        :param dispatch_at_to:
        :type dispatch_at_to: str
        :param sort_by: id|dispatch_at
        :type sort_by: str
        :param sort_dir: asc|desc
        :type sort_dir: str
        :param all: Return all items without pagination
        :type all: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_items_im_mailing_get_serialize(
            page=page,
            per_page=per_page,
            include_deleted=include_deleted,
            include=include,
            im_insurer_id=im_insurer_id,
            has_invoice=has_invoice,
            email_search_status=email_search_status,
            invoice_status=invoice_status,
            status=status,
            result=result,
            dispatch_at_from=dispatch_at_from,
            dispatch_at_to=dispatch_at_to,
            sort_by=sort_by,
            sort_dir=sort_dir,
            all=all,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataPageIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def list_items_im_mailing_get_with_http_info(
        self,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (1-based)")] = None,
        per_page: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Items per page (max 100)")] = None,
        include_deleted: Annotated[Optional[StrictBool], Field(description="Include soft-deleted")] = None,
        include: Annotated[Optional[StrictStr], Field(description="Comma-separated: organization,insurance,insurer,invoice,sro")] = None,
        im_insurer_id: Optional[StrictInt] = None,
        has_invoice: Optional[StrictBool] = None,
        email_search_status: Optional[EmailSearchStatus] = None,
        invoice_status: Optional[InvoiceStatus] = None,
        status: Optional[MailingStatus] = None,
        result: Optional[MailingResult] = None,
        dispatch_at_from: Optional[StrictStr] = None,
        dispatch_at_to: Optional[StrictStr] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="id|dispatch_at")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="asc|desc")] = None,
        all: Annotated[Optional[StrictBool], Field(description="Return all items without pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResponseDataPageIMMailingOut]:
        """List Items


        :param page: Page number (1-based)
        :type page: int
        :param per_page: Items per page (max 100)
        :type per_page: int
        :param include_deleted: Include soft-deleted
        :type include_deleted: bool
        :param include: Comma-separated: organization,insurance,insurer,invoice,sro
        :type include: str
        :param im_insurer_id:
        :type im_insurer_id: int
        :param has_invoice:
        :type has_invoice: bool
        :param email_search_status:
        :type email_search_status: EmailSearchStatus
        :param invoice_status:
        :type invoice_status: InvoiceStatus
        :param status:
        :type status: MailingStatus
        :param result:
        :type result: MailingResult
        :param dispatch_at_from:
        :type dispatch_at_from: str
        :param dispatch_at_to:
        :type dispatch_at_to: str
        :param sort_by: id|dispatch_at
        :type sort_by: str
        :param sort_dir: asc|desc
        :type sort_dir: str
        :param all: Return all items without pagination
        :type all: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_items_im_mailing_get_serialize(
            page=page,
            per_page=per_page,
            include_deleted=include_deleted,
            include=include,
            im_insurer_id=im_insurer_id,
            has_invoice=has_invoice,
            email_search_status=email_search_status,
            invoice_status=invoice_status,
            status=status,
            result=result,
            dispatch_at_from=dispatch_at_from,
            dispatch_at_to=dispatch_at_to,
            sort_by=sort_by,
            sort_dir=sort_dir,
            all=all,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataPageIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def list_items_im_mailing_get_without_preload_content(
        self,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (1-based)")] = None,
        per_page: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="Items per page (max 100)")] = None,
        include_deleted: Annotated[Optional[StrictBool], Field(description="Include soft-deleted")] = None,
        include: Annotated[Optional[StrictStr], Field(description="Comma-separated: organization,insurance,insurer,invoice,sro")] = None,
        im_insurer_id: Optional[StrictInt] = None,
        has_invoice: Optional[StrictBool] = None,
        email_search_status: Optional[EmailSearchStatus] = None,
        invoice_status: Optional[InvoiceStatus] = None,
        status: Optional[MailingStatus] = None,
        result: Optional[MailingResult] = None,
        dispatch_at_from: Optional[StrictStr] = None,
        dispatch_at_to: Optional[StrictStr] = None,
        sort_by: Annotated[Optional[StrictStr], Field(description="id|dispatch_at")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="asc|desc")] = None,
        all: Annotated[Optional[StrictBool], Field(description="Return all items without pagination")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Items


        :param page: Page number (1-based)
        :type page: int
        :param per_page: Items per page (max 100)
        :type per_page: int
        :param include_deleted: Include soft-deleted
        :type include_deleted: bool
        :param include: Comma-separated: organization,insurance,insurer,invoice,sro
        :type include: str
        :param im_insurer_id:
        :type im_insurer_id: int
        :param has_invoice:
        :type has_invoice: bool
        :param email_search_status:
        :type email_search_status: EmailSearchStatus
        :param invoice_status:
        :type invoice_status: InvoiceStatus
        :param status:
        :type status: MailingStatus
        :param result:
        :type result: MailingResult
        :param dispatch_at_from:
        :type dispatch_at_from: str
        :param dispatch_at_to:
        :type dispatch_at_to: str
        :param sort_by: id|dispatch_at
        :type sort_by: str
        :param sort_dir: asc|desc
        :type sort_dir: str
        :param all: Return all items without pagination
        :type all: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_items_im_mailing_get_serialize(
            page=page,
            per_page=per_page,
            include_deleted=include_deleted,
            include=include,
            im_insurer_id=im_insurer_id,
            has_invoice=has_invoice,
            email_search_status=email_search_status,
            invoice_status=invoice_status,
            status=status,
            result=result,
            dispatch_at_from=dispatch_at_from,
            dispatch_at_to=dispatch_at_to,
            sort_by=sort_by,
            sort_dir=sort_dir,
            all=all,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataPageIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_items_im_mailing_get_serialize(
        self,
        page,
        per_page,
        include_deleted,
        include,
        im_insurer_id,
        has_invoice,
        email_search_status,
        invoice_status,
        status,
        result,
        dispatch_at_from,
        dispatch_at_to,
        sort_by,
        sort_dir,
        all,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if per_page is not None:
            
            _query_params.append(('per_page', per_page))
            
        if include_deleted is not None:
            
            _query_params.append(('include_deleted', include_deleted))
            
        if include is not None:
            
            _query_params.append(('include', include))
            
        if im_insurer_id is not None:
            
            _query_params.append(('im_insurer_id', im_insurer_id))
            
        if has_invoice is not None:
            
            _query_params.append(('has_invoice', has_invoice))
            
        if email_search_status is not None:
            
            _query_params.append(('email_search_status', email_search_status.value))
            
        if invoice_status is not None:
            
            _query_params.append(('invoice_status', invoice_status.value))
            
        if status is not None:
            
            _query_params.append(('status', status.value))
            
        if result is not None:
            
            _query_params.append(('result', result.value))
            
        if dispatch_at_from is not None:
            
            _query_params.append(('dispatch_at_from', dispatch_at_from))
            
        if dispatch_at_to is not None:
            
            _query_params.append(('dispatch_at_to', dispatch_at_to))
            
        if sort_by is not None:
            
            _query_params.append(('sort_by', sort_by))
            
        if sort_dir is not None:
            
            _query_params.append(('sort_dir', sort_dir))
            
        if all is not None:
            
            _query_params.append(('all', all))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/im-mailing',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def update_item_im_mailing_item_id_patch(
        self,
        item_id: StrictInt,
        im_mailing_update: IMMailingUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResponseDataIMMailingOut:
        """Update Item


        :param item_id: (required)
        :type item_id: int
        :param im_mailing_update: (required)
        :type im_mailing_update: IMMailingUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_item_im_mailing_item_id_patch_serialize(
            item_id=item_id,
            im_mailing_update=im_mailing_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def update_item_im_mailing_item_id_patch_with_http_info(
        self,
        item_id: StrictInt,
        im_mailing_update: IMMailingUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResponseDataIMMailingOut]:
        """Update Item


        :param item_id: (required)
        :type item_id: int
        :param im_mailing_update: (required)
        :type im_mailing_update: IMMailingUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_item_im_mailing_item_id_patch_serialize(
            item_id=item_id,
            im_mailing_update=im_mailing_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def update_item_im_mailing_item_id_patch_without_preload_content(
        self,
        item_id: StrictInt,
        im_mailing_update: IMMailingUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Item


        :param item_id: (required)
        :type item_id: int
        :param im_mailing_update: (required)
        :type im_mailing_update: IMMailingUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_item_im_mailing_item_id_patch_serialize(
            item_id=item_id,
            im_mailing_update=im_mailing_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResponseDataIMMailingOut",
            '422': "HTTPValidationError",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_item_im_mailing_item_id_patch_serialize(
        self,
        item_id,
        im_mailing_update,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if item_id is not None:
            _path_params['item_id'] = item_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if im_mailing_update is not None:
            _body_params = im_mailing_update


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'HTTPBearer'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/im-mailing/{item_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from sromaster.models.email_search_status import EmailSearchStatus
from sromaster.models.im_insurer_out import IMInsurerOut
from sromaster.models.im_mailing_invoice_summary import IMMailingInvoiceSummary
from sromaster.models.insurance_out import InsuranceOut
from sromaster.models.invoice_status import InvoiceStatus
from sromaster.models.mailing_result import MailingResult
from sromaster.models.mailing_status import MailingStatus
from sromaster.models.message_status import MessageStatus
from sromaster.models.organization_public import OrganizationPublic
from sromaster.models.sro_short import SROShort
from typing import Optional, Set
from typing_extensions import Self

class IMMailingOutOutput(BaseModel):
    """
    IMMailingOutOutput
    """ # noqa: E501
    id: StrictInt
    organization_id: StrictInt
    insurance_id: StrictInt
    im_insurer_id: StrictInt
    im_sro_id: Optional[StrictInt]
    dispatch_at: Optional[datetime]
    email_search_status: EmailSearchStatus
    invoice_status: InvoiceStatus
    status: Optional[MailingStatus]
    result: Optional[MailingResult]
    message_status: Optional[MessageStatus]
    insured_sum: Optional[Annotated[str, Field(strict=True)]]
    insurance_premium: Optional[Annotated[str, Field(strict=True)]]
    has_invoice: Optional[StrictBool] = False
    invoice: Optional[IMMailingInvoiceSummary] = None
    organization: Optional[OrganizationPublic] = None
    insurance: Optional[InsuranceOut] = None
    insurer: Optional[IMInsurerOut] = None
    sro: Optional[SROShort] = None
    __properties: ClassVar[List[str]] = ["id", "organization_id", "insurance_id", "im_insurer_id", "im_sro_id", "dispatch_at", "email_search_status", "invoice_status", "status", "result", "message_status", "insured_sum", "insurance_premium", "has_invoice", "invoice", "organization", "insurance", "insurer", "sro"]

    @field_validator('insured_sum')
    def insured_sum_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$", value):
            raise ValueError(r"must validate the regular expression /^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$/")
        return value

    @field_validator('insurance_premium')
    def insurance_premium_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$", value):
            raise ValueError(r"must validate the regular expression /^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IMMailingOutOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of invoice
        if self.invoice:
            _dict['invoice'] = self.invoice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of organization
        if self.organization:
            _dict['organization'] = self.organization.to_dict()
        # override the default output from pydantic by calling `to_dict()` of insurance
        if self.insurance:
            _dict['insurance'] = self.insurance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of insurer
        if self.insurer:
            _dict['insurer'] = self.insurer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sro
        if self.sro:
            _dict['sro'] = self.sro.to_dict()
        # set to None if im_sro_id (nullable) is None
        # and model_fields_set contains the field
        if self.im_sro_id is None and "im_sro_id" in self.model_fields_set:
            _dict['im_sro_id'] = None

        # set to None if dispatch_at (nullable) is None
        # and model_fields_set contains the field
        if self.dispatch_at is None and "dispatch_at" in self.model_fields_set:
            _dict['dispatch_at'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if result (nullable) is None
        # and model_fields_set contains the field
        if self.result is None and "result" in self.model_fields_set:
            _dict['result'] = None

        # set to None if message_status (nullable) is None
        # and model_fields_set contains the field
        if self.message_status is None and "message_status" in self.model_fields_set:
            _dict['message_status'] = None

        # set to None if insured_sum (nullable) is None
        # and model_fields_set contains the field
        if self.insured_sum is None and "insured_sum" in self.model_fields_set:
            _dict['insured_sum'] = None

        # set to None if insurance_premium (nullable) is None
        # and model_fields_set contains the field
        if self.insurance_premium is None and "insurance_premium" in self.model_fields_set:
            _dict['insurance_premium'] = None

        # set to None if invoice (nullable) is None
        # and model_fields_set contains the field
        if self.invoice is None and "invoice" in self.model_fields_set:
            _dict['invoice'] = None

        # set to None if organization (nullable) is None
        # and model_fields_set contains the field
        if self.organization is None and "organization" in self.model_fields_set:
            _dict['organization'] = None

        # set to None if insurance (nullable) is None
        # and model_fields_set contains the field
        if self.insurance is None and "insurance" in self.model_fields_set:
            _dict['insurance'] = None

        # set to None if insurer (nullable) is None
        # and model_fields_set contains the field
        if self.insurer is None and "insurer" in self.model_fields_set:
            _dict['insurer'] = None

        # set to None if sro (nullable) is None
        # and model_fields_set contains the field
        if self.sro is None and "sro" in self.model_fields_set:
            _dict['sro'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IMMailingOutOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "organization_id": obj.get("organization_id"),
            "insurance_id": obj.get("insurance_id"),
            "im_insurer_id": obj.get("im_insurer_id"),
            "im_sro_id": obj.get("im_sro_id"),
            "dispatch_at": obj.get("dispatch_at"),
            "email_search_status": obj.get("email_search_status"),
            "invoice_status": obj.get("invoice_status"),
            "status": obj.get("status"),
            "result": obj.get("result"),
            "message_status": obj.get("message_status"),
            "insured_sum": obj.get("insured_sum"),
            "insurance_premium": obj.get("insurance_premium"),
            "has_invoice": obj.get("has_invoice") if obj.get("has_invoice") is not None else False,
            "invoice": IMMailingInvoiceSummary.from_dict(obj["invoice"]) if obj.get("invoice") is not None else None,
            "organization": OrganizationPublic.from_dict(obj["organization"]) if obj.get("organization") is not None else None,
            "insurance": InsuranceOut.from_dict(obj["insurance"]) if obj.get("insurance") is not None else None,
            "insurer": IMInsurerOut.from_dict(obj["insurer"]) if obj.get("insurer") is not None else None,
            "sro": SROShort.from_dict(obj["sro"]) if obj.get("sro") is not None else None
        })
        return _obj





# coding: utf-8

"""
    SRO Master API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.22
    Contact: info@nexium.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ResponsibilityLevel(str, Enum):
    """
    ResponsibilityLevel
    """

    """
    allowed enum values
    """
    ENUM_1 = '1'
    ENUM_2 = '2'
    ENUM_3 = '3'
    ENUM_4 = '4'
    ENUM_5 = '5'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ResponsibilityLevel from a JSON string"""
        return cls(json.loads(json_str))


